/*!
 * jQuery Mobile v1.0a4
 * http://jquerymobile.com/
 *
 * Copyright 2010, jQuery Project
 * Dual licensed under the MIT or GPL Version 2 licenses.
 * http://jquery.org/license
 */
/*
* jQuery Mobile Framework
* Copyright (c) jQuery Project
* Dual licensed under the MIT (MIT-LICENSE.txt) and GPL (GPL-LICENSE.txt) licenses.
* Note: Code is in draft form and is subject to change 
*/


/* A
-----------------------------------------------------------------------------------------------------------*/

.ui-bar-a {
	border: 1px solid 		#2A2A2A;
	background: 			#111111;
	color: 					#ffffff;
	font-weight: bold;
	text-shadow: 0 -1px 1px #000000;
	background-image: -moz-linear-gradient(top, 
							#3c3c3c, 
							#111111);
	background-image: -webkit-gradient(linear,left top,left bottom,
		color-stop(0, 	#3c3c3c),
		color-stop(1, 		#111111));
  	-ms-filter: "progid:DXImageTransform.Microsoft.gradient(startColorStr='#3c3c3c', EndColorStr='#111111')";
}
.ui-bar-a, 
.ui-bar-a input, 
.ui-bar-a select, 
.ui-bar-a textarea, 
.ui-bar-a button {
	font-family: Helvetica, Arial, sans-serif;
}
.ui-bar-a .ui-link-inherit {
	color: 					#fff;
}
.ui-bar-a .ui-link {
	color: 					#7cc4e7;
	font-weight: bold;
}
.ui-body-a {
	border: 1px solid 		#2A2A2A;
	background: 			#222222;
	color: 					#fff;
	 text-shadow: 0 1px 0 	#000;
	font-weight: normal;
	background-image: -moz-linear-gradient(top, 
							#666666, 
							#222222);
	background-image: -webkit-gradient(linear,left top,left bottom,
		color-stop(0, 		#666666),
		color-stop(1, 		#222222));
	-ms-filter: "progid:DXImageTransform.Microsoft.gradient(startColorStr='#666666', EndColorStr='#222222)')";
}
.ui-body-a,
.ui-body-a input,
.ui-body-a select,
.ui-body-a textarea,
.ui-body-a button {
	font-family: Helvetica, Arial, sans-serif;
}
.ui-body-a .ui-link-inherit {
	color: 					#fff;
}
.ui-body-a .ui-link {
	color: 					#2489CE;
	font-weight: bold;
}
.ui-br {
	border-bottom: rgb(130,130,130);
	border-bottom: rgba(130,130,130,.3);
	border-bottom-width: 1px;
	border-bottom-style: solid;
}
.ui-btn-up-a {
	border: 1px solid 		#222;
	background: 			#333333;
	font-weight: bold;
	color: 					#fff;
	text-shadow: 0 -1px 1px #000;
	background-image: -moz-linear-gradient(top, 
							#555555, 
							#333333);
	background-image: -webkit-gradient(linear,left top,left bottom,
		color-stop(0, 		#555555),
		color-stop(1, 		#333333));
	-ms-filter: "progid:DXImageTransform.Microsoft.gradient(startColorStr='#555555', EndColorStr='#333333')";
}
.ui-btn-up-a a.ui-link-inherit {
	color: 					#fff;
}
.ui-btn-hover-a {
	border: 1px solid 		#000;
	background: 			#444444;
	font-weight: bold;
	color: 					#fff;
	text-shadow: 0 -1px 1px #000;
	background-image: -moz-linear-gradient(top, 
							#666666, 
							#444444);
	background-image: -webkit-gradient(linear,left top,left bottom,
		color-stop(0, 		#666666),
		color-stop(1, 		#444444));
	-ms-filter: "progid:DXImageTransform.Microsoft.gradient(startColorStr='#666666', EndColorStr='#444444')";
}
.ui-btn-hover-a a.ui-link-inherit {
	color: 					#fff;
}
.ui-btn-down-a {
	border: 1px solid 		#000;
	background: 			#3d3d3d;
	font-weight: bold;
	color: 					#fff;
	text-shadow: 0 -1px 1px #000;
	background-image: -moz-linear-gradient(top, 
							#333333, 
							#5a5a5a);
	background-image: -webkit-gradient(linear,left top,left bottom,
		color-stop(0, 		#333333),
		color-stop(1, 		#5a5a5a));
	-ms-filter: "progid:DXImageTransform.Microsoft.gradient(startColorStr='#333333', EndColorStr='#5a5a5a')";
}
.ui-btn-down-a a.ui-link-inherit {
	color: 					#fff;
}
.ui-btn-up-a,
.ui-btn-hover-a,
.ui-btn-down-a {
	font-family: Helvetica, Arial, sans-serif;
	text-decoration: none;
}


/* B
-----------------------------------------------------------------------------------------------------------*/

.ui-bar-b {
	border: 1px solid 		#456f9a;
	background: 			#5e87b0;
	color: 					#fff;
	font-weight: bold;
	text-shadow: 0 -1px 1px #254f7a;
	background-image: -moz-linear-gradient(top, 
							#81a8ce, 
							#5e87b0);
	background-image: -webkit-gradient(linear,left top,left bottom,
		color-stop(0, 		#81a8ce),
		color-stop(1, 		#5e87b0));
	-ms-filter: "progid:DXImageTransform.Microsoft.gradient(startColorStr='#81a8ce', EndColorStr='#5e87b0')";
}
.ui-bar-b,
.ui-bar-b input,
.ui-bar-b select,
.ui-bar-b textarea,
.ui-bar-b button {
	font-family: Helvetica, Arial, sans-serif;
}
.ui-bar-b .ui-link-inherit {
	color: 					#fff;
}
.ui-bar-b .ui-link {
	color: 					#7cc4e7;
	font-weight: bold;
}

.ui-body-b {
	border: 1px solid 		#C6C6C6;
	background: 			#cccccc;
	color: 					#333333;
	text-shadow: 0 1px 0 	#fff;
	font-weight: normal;
	background-image: -moz-linear-gradient(top, 
							#e6e6e6, 
							#cccccc);
	background-image: -webkit-gradient(linear,left top,left bottom,
		color-stop(0, 		#e6e6e6),
		color-stop(1, 		#cccccc));
	 -ms-filter: "progid:DXImageTransform.Microsoft.gradient(startColorStr='#e6e6e6', EndColorStr='#cccccc')";
}
.ui-body-b,
.ui-body-b input,
.ui-body-b select,
.ui-body-b textarea,
.ui-body-b button {
	font-family: Helvetica, Arial, sans-serif;
}
.ui-body-b .ui-link-inherit {
	color: 					#333333;
}
.ui-body-b .ui-link {
	color: 					#2489CE;
	font-weight: bold;
}
.ui-btn-up-b {
	border: 1px solid 		#145072;
	background: 			#2567ab;
	font-weight: bold;
	color: 					#fff;
	text-shadow: 0 -1px 1px #145072;
	background-image: -moz-linear-gradient(top, 
							#4e89c5, 
							#2567ab);
	background-image: -webkit-gradient(linear,left top,left bottom,
			color-stop(0, 	#5f9cc5),
			color-stop(1, 	#396b9e));
	-ms-filter: "progid:DXImageTransform.Microsoft.gradient(startColorStr='#4e89c5', EndColorStr='#2567ab')";
}
.ui-btn-up-b a.ui-link-inherit {
	color: 					#fff;
}
.ui-btn-hover-b {
	border: 1px solid 		#00516e;
	background: 			#4b88b6;
	font-weight: bold;
	color: 					#fff;
	text-shadow: 0 -1px 1px #014D68;
	background-image: -moz-linear-gradient(top, 
							#72b0d4, 
							#4b88b6);
	background-image: -webkit-gradient(linear,left top,left bottom,
			color-stop(0, 	#72b0d4),
			color-stop(1, 	#4b88b6));
	-ms-filter: "progid:DXImageTransform.Microsoft.gradient(startColorStr='#72b0d4', EndColorStr='#4b88b6')";
}
.ui-btn-hover-b a.ui-link-inherit {
	color: 					#fff;
}
.ui-btn-down-b {
	border: 1px solid 		#225377;
	background: 			#4e89c5;
	font-weight: bold;
	color: 					#fff;
	text-shadow: 0 -1px 1px #225377;
	background-image: -moz-linear-gradient(top, 
							#396b9e, 
							#4e89c5);
	background-image: -webkit-gradient(linear,left top,left bottom,
		color-stop(0, 		#396b9e),
		color-stop(1, 		#4e89c5));
	-ms-filter: "progid:DXImageTransform.Microsoft.gradient(startColorStr='#396b9e', EndColorStr='#4e89c5')";
}
.ui-btn-down-b a.ui-link-inherit {
	color: 					#fff;
}
.ui-btn-up-b,
.ui-btn-hover-b,
.ui-btn-down-b {
	font-family: Helvetica, Arial, sans-serif;
	text-decoration: none;
}


/* C
-----------------------------------------------------------------------------------------------------------*/

.ui-bar-c {
	border: 1px solid 		#B3B3B3;
	background: 			#e9eaeb;
	color: 					#3E3E3E;
	font-weight: bold;
	text-shadow: 0 1px 1px 	#fff;
	background-image: -moz-linear-gradient(top, 
							#f0f0f0,
							#e9eaeb);
	background-image: -webkit-gradient(linear,left top,left bottom,
			color-stop(0, 	#f0f0f0),
			color-stop(1, 	#e9eaeb));
	-ms-filter: "progid:DXImageTransform.Microsoft.gradient(startColorStr='#f0f0f0', EndColorStr='#e9eaeb')";
}
.ui-bar-c,
.ui-bar-c input,
.ui-bar-c select,
.ui-bar-c textarea,
.ui-bar-c button {
	font-family: Helvetica, Arial, sans-serif;
}
.ui-body-c {
	border: 1px solid 		#B3B3B3;
	color: 					#333333;
	text-shadow: 0 1px 0 	#fff;
	background: 			#f0f0f0;
	background-image: -moz-linear-gradient(top, 
							#eeeeee, 
							#dddddd);
	background-image: -webkit-gradient(linear,left top,left bottom,
		color-stop(0, 		#eeeeee),
		color-stop(1, 		#dddddd));
	-ms-filter: "progid:DXImageTransform.Microsoft.gradient(startColorStr='#eeeeee', EndColorStr='#dddddd')";
}
.ui-body-c,
.ui-body-c input,
.ui-body-c select,
.ui-body-c textarea,
.ui-body-c button {
	font-family: Helvetica, Arial, sans-serif;
}
.ui-body-c .ui-link-inherit {
	color: 					#333333;
}
.ui-body-c .ui-link {
	color: 					#2489CE;
	font-weight: bold;
}

.ui-btn-up-c {
	border: 1px solid 		#ccc;
	background: 			#eee;
	font-weight: bold;
	color: 					#444;
	text-shadow: 0 1px 1px #f6f6f6;
	background-image: -moz-linear-gradient(top, 
							#fefefe, 
							#eeeeee);
	background-image: -webkit-gradient(linear,left top,left bottom,
		color-stop(0, 		#fdfdfd),
		color-stop(1, 		#eeeeee));
	-ms-filter: "progid:DXImageTransform.Microsoft.gradient(startColorStr='#fdfdfd', EndColorStr='#eeeeee')";
}
.ui-btn-up-c a.ui-link-inherit {
	color: 					#2F3E46;
}

.ui-btn-hover-c {
	border: 1px solid 		#bbb;
	background: 			#dadada;
	font-weight: bold;
	color: 					#101010;
	text-shadow: 0 1px 1px 	#fff;
	background-image: -moz-linear-gradient(top, 
							#ededed, 
							#dadada);
	background-image: -webkit-gradient(linear,left top,left bottom,
		color-stop(0, 		#ededed),
		color-stop(1, 		#dadada));
	-ms-filter: "progid:DXImageTransform.Microsoft.gradient(startColorStr='#ededed', EndColorStr='#dadada')";
}
.ui-btn-hover-c a.ui-link-inherit {
	color: 					#2F3E46;
}
.ui-btn-down-c {
	border: 1px solid 		#808080;
	background: 			#fdfdfd;
	font-weight: bold;
	color: 					#111111;
	text-shadow: 0 1px 1px 	#ffffff;
	background-image: -moz-linear-gradient(top, 
							#eeeeee, 
							#fdfdfd);
	background-image: -webkit-gradient(linear,left top,left bottom,
		color-stop(0, 		#eeeeee),
		color-stop(1, 		#fdfdfd));
  	-ms-filter: "progid:DXImageTransform.Microsoft.gradient(startColorStr='#eeeeee', EndColorStr='#fdfdfd')";
}
.ui-btn-down-c a.ui-link-inherit {
	color: 					#2F3E46;
}
.ui-btn-up-c,
.ui-btn-hover-c,
.ui-btn-down-c {
	font-family: Helvetica, Arial, sans-serif;
	text-decoration: none;
}


/* D
-----------------------------------------------------------------------------------------------------------*/

.ui-bar-d {
	border: 1px solid 		#ccc;
	background: 			#bbb;
	color: 					#333;
	text-shadow: 0 1px 0 #eee;
	background-image: -moz-linear-gradient(top, 
							#ddd, 
							#bbb);
	background-image: -webkit-gradient(linear,left top,left bottom,
		color-stop(0, 		#ddd),
		color-stop(1, 		#bbb));
  	-ms-filter: "progid:DXImageTransform.Microsoft.gradient(startColorStr='#dddddd', EndColorStr='#bbbbbb')";
}
.ui-bar-d,
.ui-bar-d input,
.ui-bar-d select,
.ui-bar-d textarea,
.ui-bar-d button {
	font-family: Helvetica, Arial, sans-serif;
}
.ui-bar-d .ui-link-inherit {
	color: 					#333;
}
.ui-bar-d .ui-link {
	color: 					#2489CE;
	font-weight: bold;
}
.ui-body-d {
	border: 1px solid 		#ccc;
	color: 					#333333;
	text-shadow: 0 1px 0 	#fff;
	background: 			#ffffff;
}
.ui-body-d,
.ui-body-d input,
.ui-body-d select,
.ui-body-d textarea,
.ui-body-d button {
	font-family: Helvetica, Arial, sans-serif;
}
.ui-body-d .ui-link-inherit {
	color: 					#333333;
}
.ui-body-d .ui-link {
	color: 					#2489CE;
	font-weight: bold;
}
.ui-btn-up-d {
	border: 1px solid 		#ccc;
	background: 			#fff;
	font-weight: bold;
	color: 					#444;
	text-shadow: 0 1px 1px #fff;
}
.ui-btn-up-d a.ui-link-inherit {
	color: 					#333;
}
.ui-btn-hover-d {
	border: 1px solid 		#aaa;
	background: 			#eeeeee;
	font-weight: bold;
	color: 					#222;
	cursor: pointer;
	text-shadow: 0 1px 1px 	#fff;
	background-image: -moz-linear-gradient(top, 
							#fdfdfd, 
							#eeeeee);
	background-image: -webkit-gradient(linear,left top,left bottom,
		color-stop(0, 		#fdfdfd),
		color-stop(1, 		#eeeeee));
  	-ms-filter: "progid:DXImageTransform.Microsoft.gradient(startColorStr='#fdfdfd', EndColorStr='#eeeeee')";
}
.ui-btn-hover-d a.ui-link-inherit {
	color: 					#222;
}
.ui-btn-down-d {
	border: 1px solid 		#aaaaaa;
	background: 			#ffffff;
	font-weight: bold;
	color: 					#111;
	text-shadow: 0 1px 1px 	#ffffff;
	background-image: -moz-linear-gradient(top, 
							#eeeeee, 
							#ffffff);
	background-image: -webkit-gradient(linear,left top,left bottom,
		color-stop(0, 		#eeeeee),
		color-stop(1, 		#ffffff));
  	-ms-filter: "progid:DXImageTransform.Microsoft.gradient(startColorStr='#eeeeee', EndColorStr='#ffffff')";
}
.ui-btn-down-d a.ui-link-inherit {
	border: 1px solid 		#808080;
	background: 			#ced0d2;
	font-weight: bold;
	color: 					#111;
	text-shadow: none;
	background-image: -moz-linear-gradient(top, 
							#cccccc, 
							#eeeeee);
	background-image: -webkit-gradient(linear,left top,left bottom,
		color-stop(0, 		#cccccc),
		color-stop(1, 		#eeeeee));
  	-ms-filter: "progid:DXImageTransform.Microsoft.gradient(startColorStr='#cccccc', EndColorStr='#eeeeee')";
}
.ui-btn-up-d,
.ui-btn-hover-d,
.ui-btn-down-d {
	font-family: Helvetica, Arial, sans-serif;
	text-decoration: none;
}


/* E
-----------------------------------------------------------------------------------------------------------*/

.ui-bar-e {
	border: 1px solid 		#F7C942;
	background: 			#fadb4e;
	color: 					#333;
	text-shadow: 0 1px 0 	#fff;
	background-image: -moz-linear-gradient(top, 
							#fceda7, 
							#fadb4e);
	background-image: -webkit-gradient(linear,left top,left bottom,
		color-stop(0, 		#fceda7),
		color-stop(1, 		#fadb4e));
  	-ms-filter: "progid:DXImageTransform.Microsoft.gradient(startColorStr='#fceda7', EndColorStr='#fadb4e')";
}
.ui-bar-e,
.ui-bar-e input,
.ui-bar-e select,
.ui-bar-e textarea,
.ui-bar-d button {
	font-family: Helvetica, Arial, sans-serif;
}
.ui-bar-e .ui-link-inherit {
	color: 					#333;
}
.ui-bar-e .ui-link {
	color: 					#2489CE;
	font-weight: bold;
}
.ui-body-e {
	border: 1px solid 		#F7C942;
	color: 					#333333;
	text-shadow: 0 1px 0 	#fff;
	background: 			#faeb9e;
	background-image: -moz-linear-gradient(top, 
							#fff, 
							#faeb9e);
	background-image: -webkit-gradient(linear,left top,left bottom,
		color-stop(0, 		#fff),
		color-stop(1, 		#faeb9e));
  	-ms-filter: "progid:DXImageTransform.Microsoft.gradient(startColorStr='#ffffff', EndColorStr='#faeb9e')";
}
.ui-body-e,
.ui-body-e input,
.ui-body-e select,
.ui-body-e textarea,
.ui-body-e button {
	font-family: Helvetica, Arial, sans-serif;
}
.ui-body-e .ui-link-inherit {
	color: 					#333333;
}
.ui-body-e .ui-link {
	color: 					#2489CE;
	font-weight: bold;
}
.ui-btn-up-e {
	border: 1px solid 		#F7C942;
	background: 			#fadb4e;
	font-weight: bold;
	color: 					#333;
	text-shadow: 0 1px 1px 	#fe3;
	text-shadow: 0 1px 0 	#fff;
	background-image: -moz-linear-gradient(top, 
							#fceda7, 
							#fadb4e);
	background-image: -webkit-gradient(linear,left top,left bottom,
		color-stop(0, 		#fceda7),
		color-stop(1, 		#fadb4e));
	-ms-filter: "progid:DXImageTransform.Microsoft.gradient(startColorStr='#fceda7', EndColorStr='#fadb4e')";
}
.ui-btn-up-e a.ui-link-inherit {
	color: 					#333;
}
.ui-btn-hover-e {
	border: 1px solid 		#e79952;
	background: 			#fbe26f;
	font-weight: bold;
	color: 					#111;
	text-shadow: 0 1px 1px 	#fff;
	background-image: -moz-linear-gradient(top, 
							#fcf0b5, 
							#fbe26f);
	background-image: -webkit-gradient(linear,left top,left bottom,
		color-stop(0, 		#fcf0b5),
		color-stop(1, 		#fbe26f));
  	-ms-filter: "progid:DXImageTransform.Microsoft.gradient(startColorStr='#fcf0b5', EndColorStr='#fbe26f')";
}

.ui-btn-hover-e a.ui-link-inherit {
	color: 					#333;
}
.ui-btn-down-e {
	border: 1px solid 		#F7C942;
	background: 			#fceda7;
	font-weight: bold;
	color: 					#111;
	text-shadow: 0 1px 1px 	#ffffff;
	background-image: -moz-linear-gradient(top, 
							#fadb4e, 
							#fceda7);
	background-image: -webkit-gradient(linear,left top,left bottom,
		color-stop(0, 		#fadb4e),
		color-stop(1, 		#fceda7));
	-ms-filter: "progid:DXImageTransform.Microsoft.gradient(startColorStr='#fadb4e', EndColorStr='#fceda7')";
}
.ui-btn-down-e a.ui-link-inherit {
	color: 					#333;
}
.ui-btn-up-e,
.ui-btn-hover-e,
.ui-btn-down-e {
	font-family: Helvetica, Arial, sans-serif;
	text-decoration: none;
}


/* links within "buttons" 
-----------------------------------------------------------------------------------------------------------*/

a.ui-link-inherit {
	text-decoration: none !important;
}


/* Active class used as the "on" state across all themes
-----------------------------------------------------------------------------------------------------------*/

.ui-btn-active {
	border: 1px solid 		#155678;
	background: 			#4596ce;
	font-weight: bold;
	color: 					#fff;
	cursor: pointer;
	text-shadow: 0 -1px 1px #145072;
	text-decoration: none;
	background-image: -moz-linear-gradient(top, 
							#85bae4, 
							#5393c5);
	background-image: -webkit-gradient(linear,left top,left bottom,
		color-stop(0, 		#85bae4),
		color-stop(1, 		#5393c5));
  	-ms-filter: "progid:DXImageTransform.Microsoft.gradient(startColorStr='#85bae4', EndColorStr='#5393c5')";
  	outline: none;
}
.ui-btn-active a.ui-link-inherit {
	color: 					#fff;
}


/* button inner top highlight
-----------------------------------------------------------------------------------------------------------*/

.ui-btn-inner {
	border-top: 1px solid 	#fff;
	border-color: 			rgba(255,255,255,.3);
}


/* corner rounding classes
-----------------------------------------------------------------------------------------------------------*/

.ui-corner-tl {
	-moz-border-radius-topleft: 		.6em;
	-webkit-border-top-left-radius: 	.6em;
	border-top-left-radius: 			.6em;
}
.ui-corner-tr {
	-moz-border-radius-topright: 		.6em;
	-webkit-border-top-right-radius: 	.6em;
	border-top-right-radius: 			.6em;
}
.ui-corner-bl {
	-moz-border-radius-bottomleft: 		.6em;
	-webkit-border-bottom-left-radius: 	.6em;
	border-bottom-left-radius: 			.6em;
}
.ui-corner-br {
	-moz-border-radius-bottomright: 	.6em;
	-webkit-border-bottom-right-radius: .6em;
	border-bottom-right-radius: 		.6em;
}
.ui-corner-top {
	-moz-border-radius-topleft: 		.6em;
	-webkit-border-top-left-radius: 	.6em;
	border-top-left-radius: 			.6em;
	-moz-border-radius-topright: 		.6em;
	-webkit-border-top-right-radius: 	.6em;
	border-top-right-radius: 			.6em;
}
.ui-corner-bottom {
	-moz-border-radius-bottomleft: 		.6em;
	-webkit-border-bottom-left-radius: 	.6em;
	border-bottom-left-radius: 			.6em;
	-moz-border-radius-bottomright: 	.6em;
	-webkit-border-bottom-right-radius: .6em;
	border-bottom-right-radius: 		.6em;
	}
.ui-corner-right {
	-moz-border-radius-topright: 		.6em;
	-webkit-border-top-right-radius: 	.6em;
	border-top-right-radius: 			.6em;
	-moz-border-radius-bottomright: 	.6em;
	-webkit-border-bottom-right-radius: .6em;
	border-bottom-right-radius: 		.6em;
}
.ui-corner-left {
	-moz-border-radius-topleft: 		.6em;
	-webkit-border-top-left-radius: 	.6em;
	border-top-left-radius: 			.6em;
	-moz-border-radius-bottomleft: 		.6em;
	-webkit-border-bottom-left-radius: 	.6em;
	border-bottom-left-radius: 			.6em;
}
.ui-corner-all {
	-moz-border-radius: 				.6em;
	-webkit-border-radius: 				.6em;
	border-radius: 						.6em;
}



/* Interaction cues
-----------------------------------------------------------------------------------------------------------*/
.ui-disabled {
	opacity: 							.3;
}
.ui-disabled,
.ui-disabled a {
	cursor: default !important;
}

/* Icons
-----------------------------------------------------------------------------------------------------------*/

.ui-icon {
	background: 						#666;
	background: 						rgba(0,0,0,.4);
	background-image: url(images/icons-18-white.png);
	background-repeat: no-repeat;
	-moz-border-radius: 				9px;
	-webkit-border-radius: 				9px;
	border-radius: 						9px;
}


/* Alt icon color
-----------------------------------------------------------------------------------------------------------*/

.ui-icon-alt {
	background: 						#fff;
	background: 						rgba(255,255,255,.3);
	background-image: url(images/icons-18-black.png);
	background-repeat: no-repeat;
}

/* HD/"retina" sprite
-----------------------------------------------------------------------------------------------------------*/

@media only screen and (-webkit-min-device-pixel-ratio: 1.5),
       only screen and (min--moz-device-pixel-ratio: 1.5),
       only screen and (min-resolution: 240dpi) {
	
	.ui-icon-plus, .ui-icon-minus, .ui-icon-delete, .ui-icon-arrow-r,
	.ui-icon-arrow-l, .ui-icon-arrow-u, .ui-icon-arrow-d, .ui-icon-check,
	.ui-icon-gear, .ui-icon-refresh, .ui-icon-forward, .ui-icon-back,
	.ui-icon-grid, .ui-icon-star, .ui-icon-alert, .ui-icon-info, .ui-icon-home, .ui-icon-search, 
	.ui-icon-checkbox-off, .ui-icon-checkbox-on, .ui-icon-radio-off, .ui-icon-radio-on {
		background-image: url(images/icons-36-white.png);
		-moz-background-size: 776px 18px;
		-o-background-size: 776px 18px;
		-webkit-background-size: 776px 18px;
		background-size: 776px 18px;
	}
	.ui-icon-alt {
		background-image: url(images/icons-36-black.png);
	}
}

/* plus minus */
.ui-icon-plus {
	background-position: 	-0 50%;
}
.ui-icon-minus {
	background-position: 	-36px 50%;
}

/* delete/close */
.ui-icon-delete {
	background-position: 	-72px 50%;
}

/* arrows */
.ui-icon-arrow-r {
	background-position: 	-108px 50%;
}
.ui-icon-arrow-l {
	background-position: 	-144px 50%;
}
.ui-icon-arrow-u {
	background-position: 	-180px 50%;
}
.ui-icon-arrow-d {
	background-position: 	-216px 50%;
}

/* misc */
.ui-icon-check {
	background-position: 	-252px 50%;
}
.ui-icon-gear {
	background-position: 	-288px 50%;
}
.ui-icon-refresh {
	background-position: 	-324px 50%;
}
.ui-icon-forward {
	background-position: 	-360px 50%;
}
.ui-icon-back {
	background-position: 	-396px 50%;
}
.ui-icon-grid {
	background-position: 	-432px 50%;
}
.ui-icon-star {
	background-position: 	-468px 50%;
}
.ui-icon-alert {
	background-position: 	-504px 50%;
}
.ui-icon-info {
	background-position: 	-540px 50%;
}
.ui-icon-home {
	background-position: 	-576px 50%;
}
.ui-icon-search {
	background-position: 	-612px 50%;
}
.ui-icon-checkbox-off {
	background-position: 	-684px 50%;
}
.ui-icon-checkbox-on {
	background-position: 	-648px 50%;
}
.ui-icon-radio-off {
	background-position: 	-756px 50%;
}
.ui-icon-radio-on {
	background-position: 	-720px 50%;
}


/* checks,radios */
.ui-icon-checkbox-off,
.ui-icon-checkbox-on,
.ui-icon-radio-off,
.ui-icon-radio-on {
	background-color: transparent;
	-moz-border-radius: 0;
	-webkit-border-radius: 0;
	border-radius: 0;
}
.ui-icon-searchfield {
	background-image: url(images/icon-search-black.png);
	background-size: 16px 16px;
}

/* loading icon */
.ui-icon-loading {
	background-image: url(images/ajax-loader.png);
	width: 40px;
	height: 40px;
	-moz-border-radius: 20px;
	-webkit-border-radius: 20px;
	border-radius: 20px;
	background-size: 35px 35px;
}


/* Button corner classes
-----------------------------------------------------------------------------------------------------------*/

.ui-btn-corner-tl {
	-moz-border-radius-topleft: 		1em;
	-webkit-border-top-left-radius: 	1em;
	border-top-left-radius: 			1em;
}
.ui-btn-corner-tr {
	-moz-border-radius-topright: 		1em;
	-webkit-border-top-right-radius: 	1em;
	border-top-right-radius: 			1em;
}
.ui-btn-corner-bl {
	-moz-border-radius-bottomleft: 		1em;
	-webkit-border-bottom-left-radius: 	1em;
	border-bottom-left-radius: 			1em;
}
.ui-btn-corner-br {
	-moz-border-radius-bottomright: 	1em;
	-webkit-border-bottom-right-radius: 1em;
	border-bottom-right-radius: 		1em;
}
.ui-btn-corner-top {
	-moz-border-radius-topleft: 		1em;
	-webkit-border-top-left-radius: 	1em;
	border-top-left-radius: 			1em;
	-moz-border-radius-topright: 		1em;
	-webkit-border-top-right-radius: 	1em;
	border-top-right-radius: 			1em;
}
.ui-btn-corner-bottom {
	-moz-border-radius-bottomleft: 		1em;
	-webkit-border-bottom-left-radius: 	1em;
	border-bottom-left-radius: 			1em;
	-moz-border-radius-bottomright: 	1em;
	-webkit-border-bottom-right-radius: 1em;
	border-bottom-right-radius: 		1em;
}
.ui-btn-corner-right {
	 -moz-border-radius-topright: 		1em;
	-webkit-border-top-right-radius: 	1em;
	border-top-right-radius: 			1em;
	-moz-border-radius-bottomright: 	1em;
	-webkit-border-bottom-right-radius: 1em;
	border-bottom-right-radius: 		1em;
}
.ui-btn-corner-left {
	-moz-border-radius-topleft: 		1em;
	-webkit-border-top-left-radius: 	1em;
	border-top-left-radius: 			1em;
	-moz-border-radius-bottomleft: 		1em;
	-webkit-border-bottom-left-radius: 	1em;
	border-bottom-left-radius: 			1em;
}
.ui-btn-corner-all {
	-moz-border-radius: 				1em;
	-webkit-border-radius: 				1em;
	border-radius: 						1em;
}

/* radius clip workaround for cleaning up corner trapping */
.ui-corner-tl,
.ui-corner-tr,
.ui-corner-bl, 
.ui-corner-br,
.ui-corner-top,
.ui-corner-bottom, 
.ui-corner-right,
.ui-corner-left,
.ui-corner-all,
.ui-btn-corner-tl,
.ui-btn-corner-tr,
.ui-btn-corner-bl, 
.ui-btn-corner-br,
.ui-btn-corner-top,
.ui-btn-corner-bottom, 
.ui-btn-corner-right,
.ui-btn-corner-left,
.ui-btn-corner-all {
  -webkit-background-clip: padding-box;
     -moz-background-clip: padding-box;
          background-clip: padding-box;
}

/* Overlay / modal
-----------------------------------------------------------------------------------------------------------*/

.ui-overlay {
	background: #666;
	opacity: .5;
	filter: Alpha(Opacity=50);
	position: absolute;
	width: 100%;
	height: 100%;
}
.ui-overlay-shadow {
	-moz-box-shadow: 0px 0px 12px 			rgba(0,0,0,.6);
	-webkit-box-shadow: 0px 0px 12px 		rgba(0,0,0,.6);
	box-shadow: 0px 0px 12px 				rgba(0,0,0,.6);
}
.ui-shadow {
	-moz-box-shadow: 0px 1px 4px 			rgba(0,0,0,.3);
	-webkit-box-shadow: 0px 1px 4px 		rgba(0,0,0,.3);
	box-shadow: 0px 1px 4px 				rgba(0,0,0,.3);
}
.ui-bar-a .ui-shadow,
.ui-bar-b .ui-shadow ,
.ui-bar-c .ui-shadow  {
	-moz-box-shadow: 0px 1px 0 				rgba(255,255,255,.3);
	-webkit-box-shadow: 0px 1px 0 			rgba(255,255,255,.3);
	box-shadow: 0px 1px 0 					rgba(255,255,255,.3);
}
.ui-shadow-inset {
	-moz-box-shadow: inset 0px 1px 4px 		rgba(0,0,0,.2);
	-webkit-box-shadow: inset 0px 1px 4px 	rgba(0,0,0,.2);
	box-shadow: inset 0px 1px 4px 			rgba(0,0,0,.2);
}
.ui-icon-shadow {
	-moz-box-shadow: 0px 1px 0 				rgba(255,255,255,.4);
	-webkit-box-shadow: 0px 1px 0 			rgba(255,255,255,.4);
	box-shadow: 0px 1px 0 					rgba(255,255,255,.4);
}


/* Focus state - set here for specificity
-----------------------------------------------------------------------------------------------------------*/

.ui-focus {
	-moz-box-shadow: 0px 0px 12px 		#387bbe;
	-webkit-box-shadow: 0px 0px 12px 	#387bbe;
	box-shadow: 0px 0px 12px 			#387bbe;
}

/* unset box shadow in browsers that don't do it right
-----------------------------------------------------------------------------------------------------------*/

.ui-mobile-nosupport-boxshadow * {
	-moz-box-shadow: none !important;
	-webkit-box-shadow: none !important;
	box-shadow: none !important;
}

/* ...and bring back focus */
.ui-mobile-nosupport-boxshadow .ui-focus {
	outline-width: 2px;
}/*
* jQuery Mobile Framework
* Copyright (c) jQuery Project
* Dual licensed under the MIT (MIT-LICENSE.txt) and GPL (GPL-LICENSE.txt) licenses.
* Note: Code is in draft form and is subject to change 
*/

/* some unsets - more probably needed */
.ui-mobile, .ui-mobile body { height: 100%; }
.ui-mobile fieldset, .ui-page { padding: 0; margin: 0; }
.ui-mobile a img, .ui-mobile fieldset { border: 0; }

/* responsive page widths */
.ui-mobile-viewport {  margin: 0; overflow-x: hidden; -webkit-text-size-adjust: none; -ms-text-size-adjust:none; -webkit-tap-highlight-color: rgba(0, 0, 0, 0); }

/* "page" containers - full-screen views, one should always be in view post-pageload */
.ui-mobile [data-role=page], .ui-mobile [data-role=dialog], .ui-page { top: 0; left: 0; width: 100%; min-height: 100%; position: absolute; display: none; border: 0; } 
.ui-mobile .ui-page-active { display: block; overflow: visible; }

/*orientations from js are available */
.portrait,
.portrait .ui-page { min-height: 100%; }
.landscape,
.landscape .ui-page  { min-height: 100%; }

/* loading screen */
.ui-loading .ui-mobile-viewport { overflow: hidden !important; }
.ui-loading .ui-loader { display: block; }
.ui-loading .ui-page { overflow: hidden;  }
.ui-loader { display: none; position: absolute; opacity: .85; z-index: 10; left: 50%; width: 200px; margin-left: -130px; margin-top: -35px; padding: 10px 30px; }
.ui-loader h1 { font-size: 15px; text-align: center; }
.ui-loader .ui-icon { position: static; display: block; opacity: .9; margin: 0 auto; width: 35px; height: 35px; background-color: transparent; }

/*fouc*/
.ui-mobile-rendering > * { visibility: hidden; }

/*headers, content panels*/
.ui-bar, .ui-body { position: relative; padding: .4em 15px;  overflow: hidden; display: block;  clear:both;  }
.ui-bar { font-size: 16px; margin: 0; }
.ui-bar h1, .ui-bar h2, .ui-bar h3, .ui-bar h4, .ui-bar h5, .ui-bar h6 { margin: 0; padding: 0; font-size: 16px; display: inline-block; }

.ui-header, .ui-footer { display: block; }
.ui-page .ui-header, .ui-page .ui-footer { position: relative; }
.ui-header .ui-btn-left { position: absolute; left: 10px; top: .4em;  }
.ui-header .ui-btn-right { position: absolute; right: 10px; top: .4em; }
.ui-header .ui-title, .ui-footer .ui-title { text-align: center; font-size: 16px; display: block; margin: .6em 90px .8em;  padding: 0;  text-overflow: ellipsis; overflow: hidden; white-space: nowrap; outline: 0 !important; }

/*content area*/
.ui-content { border-width: 0; overflow: visible; overflow-x: hidden; padding: 15px; }
.ui-page-fullscreen .ui-content { padding:0; }

/* icons sizing */
.ui-icon { width: 18px; height: 18px; }

/* fullscreen class on ui-content div */
.ui-fullscreen {  }
.ui-fullscreen img { max-width: 100%; }

/* non-js content hiding */
.ui-nojs { position: absolute; left: -9999px; }
/*
* jQuery Mobile Framework
* Copyright (c) jQuery Project
* Dual licensed under the MIT (MIT-LICENSE.txt) or GPL (GPL-LICENSE.txt) licenses.
*/
.spin  {
	-webkit-transform: rotate(360deg);
	-webkit-animation-name: spin;
	-webkit-animation-duration: 1s;
	-webkit-animation-iteration-count:  infinite;
}
@-webkit-keyframes spin {
	from {-webkit-transform: rotate(0deg);}
  	to {-webkit-transform: rotate(360deg);}
}

/* Transitions from jQtouch (with small modifications): http://www.jqtouch.com/
Built by David Kaneda and maintained by Jonathan Stark.
*/
.in, .out {
	-webkit-animation-timing-function: ease-in-out;
	-webkit-animation-duration: 350ms;
}

.slide.in {
	-webkit-transform: translateX(0);
	-webkit-animation-name: slideinfromright;
}

.slide.out {
	-webkit-transform: translateX(-100%);
	-webkit-animation-name: slideouttoleft;
}

.slide.in.reverse {
	-webkit-transform: translateX(0);
	-webkit-animation-name: slideinfromleft;
}

.slide.out.reverse {
	-webkit-transform: translateX(100%);
	-webkit-animation-name: slideouttoright;
}

.slideup.in {
	-webkit-transform: translateY(0);
	-webkit-animation-name: slideinfrombottom;
	z-index: 10;
}

.slideup.out {
	-webkit-animation-name: dontmove;
	z-index: 0;
}

.slideup.out.reverse {
	-webkit-transform: translateY(100%);
	z-index: 10;
	-webkit-animation-name: slideouttobottom;
}

.slideup.in.reverse {
	z-index: 0;
	-webkit-animation-name: dontmove;
}
.slidedown.in {
	-webkit-transform: translateY(0);
	-webkit-animation-name: slideinfromtop;
	z-index: 10;
}

.slidedown.out {
	-webkit-animation-name: dontmove;
	z-index: 0;
}

.slidedown.out.reverse {
	-webkit-transform: translateY(-100%);
	z-index: 10;
	-webkit-animation-name: slideouttotop;
}

.slidedown.in.reverse {
	z-index: 0;
	-webkit-animation-name: dontmove;
}

@-webkit-keyframes slideinfromright {
    from { -webkit-transform: translateX(100%); }
    to { -webkit-transform: translateX(0); }
}

@-webkit-keyframes slideinfromleft {
    from { -webkit-transform: translateX(-100%); }
    to { -webkit-transform: translateX(0); }
}

@-webkit-keyframes slideouttoleft {
    from { -webkit-transform: translateX(0); }
    to { -webkit-transform: translateX(-100%); }
}

@-webkit-keyframes slideouttoright {
    from { -webkit-transform: translateX(0); }
    to { -webkit-transform: translateX(100%); }
}


@-webkit-keyframes slideinfromtop {
    from { -webkit-transform: translateY(-100%); }
    to { -webkit-transform: translateY(0); }
}

@-webkit-keyframes slideinfrombottom {
    from { -webkit-transform: translateY(100%); }
    to { -webkit-transform: translateY(0); }
}

@-webkit-keyframes slideouttobottom {
    from { -webkit-transform: translateY(0); }
    to { -webkit-transform: translateY(100%); }
}

@-webkit-keyframes slideouttotop {
    from { -webkit-transform: translateY(0); }
    to { -webkit-transform: translateY(-100%); }
}
@-webkit-keyframes fadein {
    from { opacity: 0; }
    to { opacity: 1; }
}

@-webkit-keyframes fadeout {
    from { opacity: 1; }
    to { opacity: 0; }
}

.fade.in {
	opacity: 1;
	z-index: 10;
	-webkit-animation-name: fadein;
}
.fade.out {
	z-index: 0;
	-webkit-animation-name: fadeout;
}

/* The properties in this body rule are only necessary for the 'flip' transition.
 * We need specify the perspective to create a projection matrix. This will add
 * some depth as the element flips. The depth number represents the distance of
 * the viewer from the z-plane. According to the CSS3 spec, 1000 is a moderate
 * value.
 */
.ui-mobile-viewport-perspective {
	-webkit-perspective: 1000;
	position: absolute;
}

.ui-mobile-viewport-transitioning,
.ui-mobile-viewport-transitioning .ui-page {
	width: 100%;
	height: 100%;
	overflow: hidden;
}

.flip {
	-webkit-animation-duration: .65s;
	-webkit-backface-visibility:hidden;
	-webkit-transform:translateX(0); /* Needed to work around an iOS 3.1 bug that causes listview thumbs to disappear when -webkit-visibility:hidden is used. */
}

.flip.in {
	-webkit-transform: rotateY(0) scale(1);
	-webkit-animation-name: flipinfromleft;
}

.flip.out {
	-webkit-transform: rotateY(-180deg) scale(.8);
	-webkit-animation-name: flipouttoleft;
}

/* Shake it all about */

.flip.in.reverse {
	-webkit-transform: rotateY(0) scale(1);
	-webkit-animation-name: flipinfromright;
}

.flip.out.reverse {
	-webkit-transform: rotateY(180deg) scale(.8);
	-webkit-animation-name: flipouttoright;
}

@-webkit-keyframes flipinfromright {
    from { -webkit-transform: rotateY(-180deg) scale(.8); }
    to { -webkit-transform: rotateY(0) scale(1); }
}

@-webkit-keyframes flipinfromleft {
    from { -webkit-transform: rotateY(180deg) scale(.8); }
    to { -webkit-transform: rotateY(0) scale(1); }
}

@-webkit-keyframes flipouttoleft {
    from { -webkit-transform: rotateY(0) scale(1); }
    to { -webkit-transform: rotateY(-180deg) scale(.8); }
}

@-webkit-keyframes flipouttoright {
    from { -webkit-transform: rotateY(0) scale(1); }
    to { -webkit-transform: rotateY(180deg) scale(.8); }
}


/* Hackish, but reliable. */

@-webkit-keyframes dontmove {
    from { opacity: 1; }
    to { opacity: 1; }
}

.pop {
	-webkit-transform-origin: 50% 50%;
}

.pop.in {
	-webkit-transform: scale(1);
    opacity: 1;
	-webkit-animation-name: popin;
	z-index: 10;
}

.pop.out.reverse {
	-webkit-transform: scale(.2);
	opacity: 0;
	-webkit-animation-name: popout;
	z-index: 10;
}

.pop.in.reverse {
	z-index: 0;
	-webkit-animation-name: dontmove;
}

@-webkit-keyframes popin {
    from {
        -webkit-transform: scale(.2);
        opacity: 0;
    }
    to {
        -webkit-transform: scale(1);
        opacity: 1;
    }
}

@-webkit-keyframes popout {
    from {
        -webkit-transform: scale(1);
        opacity: 1;
    }
    to {
        -webkit-transform: scale(.2);
        opacity: 0;
    }
}/*
* jQuery Mobile Framework
* Copyright (c) jQuery Project
* Dual licensed under the MIT (MIT-LICENSE.txt) or GPL (GPL-LICENSE.txt) licenses.
*/

/* content configurations. */
.ui-grid-a, .ui-grid-b, .ui-grid-c, .ui-grid-d { overflow: hidden; }
.ui-block-a, .ui-block-b, .ui-block-c, .ui-block-d, .ui-block-e { margin: 0; padding: 0; border: 0; float: left; min-height:1px;}

/* grid solo: 100 - single item fallback */
.ui-grid-solo .ui-block-a { width: 100%; float: none; }

/* grid a: 50/50 */
.ui-grid-a .ui-block-a, .ui-grid-a .ui-block-b { width: 50%; }
.ui-grid-a .ui-block-a { clear: left; }

/* grid b: 33/33/33 */
.ui-grid-b .ui-block-a, .ui-grid-b .ui-block-b, .ui-grid-b .ui-block-c { width: 33.333%; }
.ui-grid-b .ui-block-a { clear: left; }

/* grid c: 25/25/25/25 */
.ui-grid-c .ui-block-a, .ui-grid-c .ui-block-b, .ui-grid-c .ui-block-c, .ui-grid-c .ui-block-d { width: 25%; }
.ui-grid-c .ui-block-a { clear: left; }

/* grid d: 20/20/20/20/20 */
.ui-grid-d .ui-block-a, .ui-grid-d .ui-block-b, .ui-grid-d .ui-block-c, .ui-grid-d .ui-block-d, .ui-grid-d .ui-block-e { width: 20%; }
.ui-grid-d .ui-block-a { clear: left; }
/*
* jQuery Mobile Framework
* Copyright (c) jQuery Project
* Dual licensed under the MIT (MIT-LICENSE.txt) or GPL (GPL-LICENSE.txt) licenses.
*/
/* fixed page header & footer configuration */
.ui-header, .ui-footer, .ui-page-fullscreen .ui-header, .ui-page-fullscreen .ui-footer  { position: absolute;  overflow: hidden; width: 100%; border-left-width: 0; border-right-width: 0; }
.ui-header-fixed, .ui-footer-fixed {
	z-index: 1000;
	-webkit-transform: translateZ(0); /* Force header/footer rendering to go through the same rendering pipeline as native page scrolling. */
}
.ui-footer-duplicate, .ui-page-fullscreen .ui-fixed-inline { display: none; }
.ui-page-fullscreen .ui-header, .ui-page-fullscreen .ui-footer { opacity: .9; }
/*
* jQuery Mobile Framework
* Copyright (c) jQuery Project
* Dual licensed under the MIT (MIT-LICENSE.txt) or GPL (GPL-LICENSE.txt) licenses.
*/
.ui-navbar { overflow: hidden;  }
.ui-navbar ul, .ui-navbar-expanded ul { list-style:none; padding: 0; margin: 0; position: relative; display: block; border: 0;}
.ui-navbar-collapsed ul { float: left; width: 75%; margin-right: -2px; }
.ui-navbar-collapsed .ui-navbar-toggle { float: left; width: 25%; }
.ui-navbar li.ui-navbar-truncate { position: absolute; left: -9999px; top: -9999px; }
.ui-navbar li .ui-btn, .ui-navbar .ui-navbar-toggle .ui-btn { display: block; font-size: 12px; text-align: center; margin: 0; border-right-width: 0; }
.ui-navbar li .ui-btn {  margin-right: -1px; }
.ui-navbar li .ui-btn:last-child { margin-right: 0; }
.ui-header .ui-navbar li .ui-btn, .ui-header .ui-navbar .ui-navbar-toggle .ui-btn,
.ui-footer .ui-navbar li .ui-btn, .ui-footer .ui-navbar .ui-navbar-toggle .ui-btn { border-top-width: 0; border-bottom-width: 0; }
.ui-navbar .ui-btn-inner { padding-left: 2px; padding-right: 2px; }
.ui-navbar-noicons li .ui-btn .ui-btn-inner, .ui-navbar-noicons .ui-navbar-toggle .ui-btn-inner { padding-top: .8em; padding-bottom: .9em; }
/*expanded page styles*/
.ui-navbar-expanded .ui-btn { margin: 0; font-size: 14px; }
.ui-navbar-expanded .ui-btn-inner { padding-left: 5px; padding-right: 5px;  }
.ui-navbar-expanded .ui-btn-icon-top .ui-btn-inner { padding: 45px 5px 15px; text-align: center; }
.ui-navbar-expanded .ui-btn-icon-top .ui-icon { top: 15px; }
.ui-navbar-expanded .ui-btn-icon-bottom .ui-btn-inner { padding: 15px 5px 45px; text-align: center; }
.ui-navbar-expanded .ui-btn-icon-bottom .ui-icon { bottom: 15px; }
.ui-navbar-expanded li .ui-btn .ui-btn-inner { min-height: 2.5em; }
.ui-navbar-expanded .ui-navbar-noicons .ui-btn .ui-btn-inner { padding-top: 1.8em; padding-bottom: 1.9em; }
/*
* jQuery Mobile Framework
* Copyright (c) jQuery Project
* Dual licensed under the MIT (MIT-LICENSE.txt) or GPL (GPL-LICENSE.txt) licenses.
*/
.ui-btn { display: block; text-align: center; cursor:pointer;  position: relative; margin: .5em 5px; padding: 0; }
.ui-btn:focus, .ui-btn:active { outline: none; }
.ui-header .ui-btn, .ui-footer .ui-btn, .ui-bar .ui-btn { display: inline-block; font-size: 13px; margin: 0; }
.ui-btn-inline { display: inline-block; }
.ui-btn-inner { padding: .6em 25px; display: block; height: 100%; text-overflow: ellipsis; overflow: hidden; white-space: nowrap; position: relative; }
.ui-header .ui-btn-inner, .ui-footer .ui-btn-inner, .ui-bar .ui-btn-inner { padding: .4em 8px .5em; }
.ui-btn-icon-notext { display: inline-block; width: 20px; height: 20px; padding: 2px 1px 2px 3px; text-indent: -9999px; }
.ui-btn-icon-notext .ui-btn-inner { padding: 0; }
.ui-btn-icon-notext .ui-btn-text { position: absolute; left: -999px; }
.ui-btn-icon-left .ui-btn-inner { padding-left: 33px; }
.ui-header .ui-btn-icon-left .ui-btn-inner,
.ui-footer .ui-btn-icon-left .ui-btn-inner,
.ui-bar .ui-btn-icon-left .ui-btn-inner { padding-left: 27px; }
.ui-btn-icon-right .ui-btn-inner { padding-right: 33px; }
.ui-header .ui-btn-icon-right .ui-btn-inner,
.ui-footer .ui-btn-icon-right .ui-btn-inner,
.ui-bar .ui-btn-icon-right .ui-btn-inner { padding-right: 27px; }
.ui-btn-icon-top .ui-btn-inner { padding-top: 33px; }
.ui-header .ui-btn-icon-top .ui-btn-inner,
.ui-footer .ui-btn-icon-top .ui-btn-inner,
.ui-bar .ui-btn-icon-top .ui-btn-inner { padding-top: 27px; }
.ui-btn-icon-bottom .ui-btn-inner { padding-bottom: 33px; }
.ui-header .ui-btn-icon-bottom .ui-btn-inner,
.ui-footer .ui-btn-icon-bottom .ui-btn-inner,
.ui-bar .ui-btn-icon-bottom .ui-btn-inner { padding-bottom: 27px; }

/*btn icon positioning*/
.ui-btn-icon-notext .ui-icon { display: block; }
.ui-btn-icon-left .ui-icon, .ui-btn-icon-right .ui-icon { position: absolute; top: 50%; margin-top: -9px; }
.ui-btn-icon-top .ui-icon, .ui-btn-icon-bottom .ui-icon { position: absolute; left: 50%;  margin-left: -9px; }
.ui-btn-icon-left .ui-icon { left: 10px; }
.ui-btn-icon-right .ui-icon {right: 10px; }
.ui-header .ui-btn-icon-left .ui-icon,
.ui-footer .ui-btn-icon-left .ui-icon,
.ui-bar .ui-btn-icon-left .ui-icon { left: 4px; }
.ui-header .ui-btn-icon-right .ui-icon,
.ui-footer .ui-btn-icon-right .ui-icon,
.ui-bar .ui-btn-icon-right .ui-icon { right: 4px; }
.ui-header .ui-btn-icon-top .ui-icon,
.ui-footer .ui-btn-icon-top .ui-icon,
.ui-bar .ui-btn-icon-top .ui-icon { top: 4px; }
.ui-header .ui-btn-icon-bottom .ui-icon,
.ui-footer .ui-btn-icon-bottom .ui-icon,
.ui-bar .ui-btn-icon-bottom .ui-icon { bottom: 4px; }
.ui-btn-icon-top .ui-icon { top: 5px; }
.ui-btn-icon-bottom .ui-icon { bottom: 5px; }
/*hiding native button,inputs */
.ui-btn-hidden {  position: absolute; top: 0; left: 0; width: 100%; height: 100%; -webkit-appearance: button; opacity: 0; cursor: pointer; -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)"; filter: alpha(opacity=0); }
/*
* jQuery Mobile Framework
* Copyright (c) jQuery Project
* Dual licensed under the MIT (MIT-LICENSE.txt) or GPL (GPL-LICENSE.txt) licenses.
*/
.ui-collapsible-contain { margin: .5em 0; }
.ui-collapsible-heading { font-size: 16px; display: block; margin: 0 -8px; padding: 0; border-width: 0 0 1px 0; position: relative; }
.ui-collapsible-heading a { text-align: left; margin: 0;  }
.ui-collapsible-heading a .ui-btn-inner { padding-left: 40px; }
.ui-collapsible-heading a span.ui-btn { position: absolute; left: 6px; top: 50%; margin: -12px 0 0 0; width: 20px; height: 20px; padding: 1px 0px 1px 2px; text-indent: -9999px; }
.ui-collapsible-heading a span.ui-btn .ui-btn-inner { padding: 0; }
.ui-collapsible-heading a span.ui-btn .ui-icon { left: 0; margin-top: -10px; }
.ui-collapsible-heading-status { position:absolute; left:-9999px; }
.ui-collapsible-content {  display: block; padding: 10px 0 10px 8px; }
.ui-collapsible-content-collapsed { display: none; }

.ui-collapsible-set { margin: .5em 0; }
.ui-collapsible-set .ui-collapsible-contain { margin: -1px 0 0; }
/*
* jQuery Mobile Framework
* Copyright (c) jQuery Project
* Dual licensed under the MIT (MIT-LICENSE.txt) or GPL (GPL-LICENSE.txt) licenses.
*/
.ui-controlgroup, fieldset.ui-controlgroup { padding: 0; margin: .5em 0 1em; }
.ui-bar .ui-controlgroup { margin: 0 .3em; }
.ui-controlgroup-label { font-size: 16px; line-height: 1.4; font-weight: normal; margin: 0 0 .3em; }
.ui-controlgroup-controls { display: block; width: 95%;}
.ui-controlgroup li { list-style: none; }
.ui-controlgroup-vertical .ui-btn,
.ui-controlgroup-vertical .ui-checkbox, .ui-controlgroup-vertical .ui-radio { margin: 0; border-bottom-width: 0;  }
.ui-controlgroup-vertical .ui-controlgroup-last { border-bottom-width: 1px; }
.ui-controlgroup-horizontal { padding: 0; }
.ui-controlgroup-horizontal .ui-btn,
.ui-controlgroup-horizontal .ui-checkbox, .ui-controlgroup-horizontal .ui-radio { display: inline-block; margin: 0 -5px 0 0; }
.ui-controlgroup-horizontal .ui-checkbox, .ui-controlgroup-horizontal .ui-radio { display: inline; }
.ui-controlgroup-horizontal .ui-checkbox .ui-btn, .ui-controlgroup-horizontal .ui-radio .ui-btn,
.ui-controlgroup-horizontal .ui-checkbox:last-child, .ui-controlgroup-horizontal .ui-radio:last-child { margin-right: 0; }
.ui-controlgroup-horizontal .ui-controlgroup-last { margin-right: 0; }
.ui-controlgroup .ui-checkbox label, .ui-controlgroup .ui-radio label { font-size: 16px;  }
/* conflicts with listview..
.ui-controlgroup .ui-btn-icon-notext { width: 30px; height: 30px; text-indent: -9999px; }
.ui-controlgroup .ui-btn-icon-notext .ui-btn-inner {  padding: 5px 6px 5px 5px; }
*/

.min-width-480px .ui-controlgroup-label { vertical-align: top; display: inline-block;  width: 20%;  margin: 0 2% 0 0;  }
.min-width-480px .ui-controlgroup-controls { width: 60%; display: inline-block; } /*
* jQuery Mobile Framework
* Copyright (c) jQuery Project
* Dual licensed under the MIT (MIT-LICENSE.txt) or GPL (GPL-LICENSE.txt) licenses.
*/
.ui-dialog { min-height: 480px; }
.ui-dialog .ui-header, .ui-dialog .ui-content,  .ui-dialog .ui-footer { margin: 15px; position: relative; }
.ui-dialog .ui-header, .ui-dialog .ui-footer { z-index: 10; width: auto; }
.ui-dialog .ui-content, .ui-dialog .ui-footer { margin-top: -15px;  }/*
* jQuery Mobile Framework
* Copyright (c) jQuery Project
* Dual licensed under the MIT (MIT-LICENSE.txt) or GPL (GPL-LICENSE.txt) licenses.
*/
.ui-checkbox, .ui-radio { position:relative;  margin: .2em 0 .5em; z-index: 1;  }
.ui-checkbox .ui-btn, .ui-radio .ui-btn { margin: 0; text-align: left; z-index: 2; }
.ui-checkbox .ui-btn-icon-left .ui-btn-inner,.ui-radio .ui-btn-icon-left .ui-btn-inner { padding-left: 45px; }
.ui-checkbox .ui-btn-icon-right .ui-btn-inner, .ui-radio .ui-btn-icon-right .ui-btn-inner { padding-right: 45px; }
.ui-checkbox .ui-btn-icon-left .ui-icon, .ui-radio .ui-btn-icon-left .ui-icon {left: 15px; }
.ui-checkbox .ui-btn-icon-right .ui-icon, .ui-radio .ui-btn-icon-right .ui-icon {right: 15px; }
/* input, label positioning */
.ui-checkbox input,.ui-radio input { position:absolute; left:20px; top:50%; width: 10px; height: 10px;  margin:-5px 0 0 0; outline: 0 !important; z-index: 1; }/*
* jQuery Mobile Framework
* Copyright (c) jQuery Project
* Dual licensed under the MIT (MIT-LICENSE.txt) or GPL (GPL-LICENSE.txt) licenses.
*/
.ui-field-contain { background: none; padding: 1.5em 0; margin: 0; border-bottom-width: 1px; overflow: visible; }
.ui-field-contain:first-child { border-top-width: 0; }
.min-width-480px .ui-field-contain { border-width: 0; padding: 0; margin: 1em 0; }/*
* jQuery Mobile Framework
* Copyright (c) jQuery Project
* Dual licensed under the MIT (MIT-LICENSE.txt) or GPL (GPL-LICENSE.txt) licenses.
*/
.ui-select { display: block; position: relative; }
.ui-select select { position: absolute; left: -9999px; top: -9999px; }
.ui-select .ui-btn { overflow: hidden; }
.ui-select .ui-btn select { cursor: pointer; -webkit-appearance: button; left: 0; top:0; width: 100%; height: 100%; opacity: 0; -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)"; filter: alpha(opacity=0); }
.ui-select .ui-btn select.ui-select-nativeonly { opacity: 1; }

.ui-select .ui-btn-icon-right .ui-btn-inner { padding-right: 45px; } 
.ui-select .ui-btn-icon-right .ui-icon { right: 15px;  }

/* labels */
label.ui-select { font-size: 16px; line-height: 1.4;  font-weight: normal; margin: 0 0 .3em; display: block; }

/*listbox*/
.ui-select .ui-btn-text, .ui-selectmenu .ui-btn-text { display: inline-block; min-height: 1em; }
.ui-select .ui-btn-text { text-overflow: ellipsis; overflow: hidden; display: block;}

.ui-selectmenu { position: absolute; padding: 0; z-index: 100 !important; width: 80%; max-width: 350px; padding: 6px; }
.ui-selectmenu .ui-listview { margin: 0; }
.ui-selectmenu .ui-btn.ui-li-divider { cursor: default; }
.ui-selectmenu-hidden { top: -9999px; left: -9999px; }
.ui-selectmenu-screen { position: absolute; top: 0; left: 0; width: 100%; height: 100%;  z-index: 99; }
.ui-screen-hidden, .ui-selectmenu-list .ui-li .ui-icon { display: none; }
.ui-selectmenu-list .ui-li .ui-icon { display: block; }
.ui-li.ui-selectmenu-placeholder { display: none; }
.ui-selectmenu .ui-header .ui-title { margin: 0.6em 46px 0.8em; }

.min-width-480px label.ui-select { display: inline-block;  width: 20%;  margin: 0 2% 0 0; }
.min-width-480px .ui-select { width: 60%; display: inline-block; }

/* when no placeholder is defined in a multiple select, the header height doesn't even extend past the close button.  this shim's content in there */
.ui-selectmenu .ui-header h1:after { content: '.'; visibility: hidden; }/*
* jQuery Mobile Framework
* Copyright (c) jQuery Project
* Dual licensed under the MIT (MIT-LICENSE.txt) or GPL (GPL-LICENSE.txt) licenses.
*/
label.ui-input-text { font-size: 16px; line-height: 1.4; display: block; font-weight: normal; margin: 0 0 .3em; }
input.ui-input-text, textarea.ui-input-text { background-image: none; padding: .4em; line-height: 1.4; font-size: 16px; display: block; width: 95%; }
input.ui-input-text { -webkit-appearance: none; }
textarea.ui-input-text { height: 50px; -webkit-transition: height 200ms linear; -moz-transition: height 200ms linear; -o-transition: height 200ms linear; transition: height 200ms linear; }
.ui-input-search { padding: 0 30px; width: 77%; background-position: 8px 50%; background-repeat: no-repeat; position: relative; }
.ui-input-search input.ui-input-text { border: none; width: 98%; padding: .4em 0; margin: 0; display: block; background: transparent none; outline: 0 !important; }
.ui-input-search .ui-input-clear { position: absolute; right: 0; top: 50%; margin-top: -14px; }
.ui-input-search .ui-input-clear-hidden { display: none; }

/* orientation adjustments - incomplete!*/
.min-width-480px label.ui-input-text  { vertical-align: top;   }
.min-width-480px label.ui-input-text { display: inline-block;  width: 20%;  margin: 0 2% 0 0; }
.min-width-480px input.ui-input-text, 
.min-width-480px textarea.ui-input-text, 
.min-width-480px .ui-input-search { width: 60%; display: inline-block; } 
.min-width-480px .ui-input-search { width: 50%; }
.min-width-480px .ui-input-search input.ui-input-text { width: 98%; /*echos rule from above*/ }
/*
* jQuery Mobile Framework
* Copyright (c) jQuery Project
* Dual licensed under the MIT (MIT-LICENSE.txt) or GPL (GPL-LICENSE.txt) licenses.
*/
.ui-listview { margin: 0; counter-reset: listnumbering; }
.ui-content .ui-listview { margin: -15px; }
.ui-content .ui-listview-inset { margin: 1em 0;  }
.ui-listview, .ui-li { list-style:none; padding:0; }
.ui-li, .ui-li.ui-field-contain { display: block; margin:0; position: relative; overflow: visible; text-align: left; border-width: 0; border-top-width: 1px; }
.ui-li .ui-btn-text a.ui-link-inherit { text-overflow: ellipsis; overflow: hidden; white-space: nowrap;  }
.ui-li-divider, .ui-li-static { padding: .5em 15px; font-size: 14px; font-weight: bold;  }
.ui-li-divider { counter-reset: listnumbering;  }
ol.ui-listview .ui-link-inherit:before, ol.ui-listview .ui-li-static:before, .ui-li-dec { font-size: .8em; display: inline-block; padding-right: .3em; font-weight: normal;counter-increment: listnumbering; content: counter(listnumbering) ". "; }
ol.ui-listview .ui-li-jsnumbering:before { content: "" !important; } /* to avoid chance of duplication */
.ui-listview-inset .ui-li { border-right-width: 1px; border-left-width: 1px; }
.ui-li:last-child, .ui-li.ui-field-contain:last-child { border-bottom-width: 1px; }
.ui-li>.ui-btn-inner { display: block; position: relative; padding: 0; }
.ui-li .ui-btn-inner a.ui-link-inherit, .ui-li-static.ui-li { padding: .7em 75px .7em 15px; display: block; }
.ui-li-has-thumb .ui-btn-inner a.ui-link-inherit, .ui-li-static.ui-li-has-thumb  { min-height: 60px; padding-left: 100px; }
.ui-li-has-icon .ui-btn-inner a.ui-link-inherit, .ui-li-static.ui-li-has-icon {  min-height: 20px; padding-left: 40px; }
.ui-li-heading { font-size: 16px; font-weight: bold; display: block; margin: .6em 0; text-overflow: ellipsis; overflow: hidden; white-space: nowrap;  }
.ui-li-desc {  font-size: 12px; font-weight: normal; display: block; margin: -.5em 0 .6em; text-overflow: ellipsis; overflow: hidden; white-space: nowrap; }
.ui-li-thumb, .ui-li-icon { position: absolute; left: 1px; top: 0; max-height: 80px; max-width: 80px; }
.ui-li-icon { max-height: 40px; max-width: 40px; left: 10px; top: .9em; }
.ui-li-thumb, .ui-li-icon, .ui-li-content { float: left; margin-right: 10px; }

.ui-li-aside { float: right; width: 50%; text-align: right; margin: .3em 0; }
.min-width-480px .ui-li-aside { width: 45%; }
.ui-li-divider { cursor: default; }
.ui-li-has-alt .ui-btn-inner a.ui-link-inherit, .ui-li-static.ui-li-has-alt { padding-right: 95px; }
.ui-li-count { position: absolute; font-size: 11px; font-weight: bold; padding: .2em .5em; top: 50%; margin-top: -.9em; right: 38px; }
.ui-li-divider .ui-li-count, .ui-li-static .ui-li-count { right: 10px; }
.ui-li-has-alt .ui-li-count { right: 55px; }
.ui-li-link-alt { position: absolute; width: 40px; height: 100%; border-width: 0; border-left-width: 1px; top: 0; right: 0; margin: 0; padding: 0; }
.ui-li-link-alt .ui-btn { overflow: hidden; position: absolute; right: 8px; top: 50%; margin: -11px 0 0 0; border-bottom-width: 1px; }
.ui-li-link-alt .ui-btn-inner { padding: 0; position: static; }
.ui-li-link-alt .ui-btn .ui-icon { right: 50%; margin-right: -9px;  }

.ui-listview-filter { border-width: 0; overflow: hidden; margin: -15px -15px 15px -15px }
.ui-listview-filter .ui-input-search { margin: 5px; width: auto; display: block; }

.ui-listview-filter-inset { margin: -15px -5px -15px -5px; background: transparent; }

/* Odd iPad positioning issue. */
@media only screen and (min-device-width: 768px) and (max-device-width: 1024px) {
    .ui-li .ui-btn-text { overflow:  visible; }
}/*
* jQuery Mobile Framework
* Copyright (c) jQuery Project
* Dual licensed under the MIT (MIT-LICENSE.txt) or GPL (GPL-LICENSE.txt) licenses.
*/
label.ui-slider { display: block; }
input.ui-slider-input, .min-width-480px input.ui-slider-input { display: inline-block; width: 50px; }
select.ui-slider-switch { display: none; }
div.ui-slider { position: relative; display: inline-block; overflow: visible; height: 15px; padding: 0; margin: 0 2% 0 20px; top: 4px; width: 66%; }
a.ui-slider-handle { position: absolute; z-index: 10;  top: 50%; width: 28px; height: 28px; margin-top: -15px; margin-left: -15px; }
a.ui-slider-handle .ui-btn-inner { padding-left: 0; padding-right: 0; }
.min-width-480px label.ui-slider { display: inline-block;  width: 20%;  margin: 0 2% 0 0; }
.min-width-480px div.ui-slider { width: 45%; }

div.ui-slider-switch { height: 32px;  overflow: hidden; margin-left: 0; }
div.ui-slider-inneroffset { margin-left: 50%; position: absolute; top: 1px; height: 100%; width: 50%; }
div.ui-slider-handle-snapping { -webkit-transition: left 100ms linear; }
div.ui-slider-labelbg { position: absolute; top:0; margin: 0; border-width: 0; }
div.ui-slider-switch div.ui-slider-labelbg-a { width: 60%; height: 100%; left: 0; }
div.ui-slider-switch div.ui-slider-labelbg-b { width: 60%; height: 100%; right: 0; }
.ui-slider-switch-a div.ui-slider-labelbg-a, .ui-slider-switch-b div.ui-slider-labelbg-b { z-index: -1; }
.ui-slider-switch-a div.ui-slider-labelbg-b, .ui-slider-switch-b div.ui-slider-labelbg-a { z-index: 0; }

div.ui-slider-switch a.ui-slider-handle { z-index: 20;  width: 101%; height: 32px; margin-top: -18px; margin-left: -101%; }
span.ui-slider-label { width: 100%; position: absolute;height: 32px;  font-size: 16px; text-align: center; line-height: 2; background: none; border-color: transparent; }
span.ui-slider-label-a { left: -100%;  margin-right: -1px }
span.ui-slider-label-b { right: -100%;  margin-left: -1px }
